@@ -961,8 +961,22 @@ class account():
 
     def parse_time(self, timestr):
         #parses a time string from twitter into a date object
+        if (timestr.find("+") == -1):
+            #negative offset from UTC
+            strippedDate = timestr[0: timestr.find("-")] + "+0000" + timestr[timestr.find("-") + 5: len(timestr)]
+            hoursOffset = int(timestr[timestr.find("-") + 1:timestr.find("-") + 3])
+            print "offset hours = -" + str(hoursOffset)
+            minus = True
+        else:
+            #positive offset from UTC
+            strippedDate = timestr[0: timestr.find("+")] + "+0000" + timestr[timestr.find("+") + 5: len(timestr)]
+            hoursOffset = int(timestr[timestr.find("+") + 1:timestr.find("+") + 3])
+            print "offset hours = +" + str(hoursOffset)
+            minus = False
         try:
-            msgDate = datetime.datetime.strptime(timestr, "%a %b %d %H:%M:%S +0000 %Y")
+
+
+            msgDate = datetime.datetime.strptime(strippedDate, "%a %b %d %H:%M:%S +0000 %Y")
             #msgDate = date.fromtimestamp(secsSinceEpoc)
 
             timestamp = msgDate.time()
@@ -976,8 +990,10 @@ class account():
                 tz = time.altzone
             else:
                 tz = time.timezone
-
-            td = datetime.timedelta(seconds=tz)
+            if (minus):
+                td = datetime.timedelta(hours=0 - hoursOffset, seconds=tz)
+            else:
+                td = datetime.timedelta(hours=hoursOffset, seconds=tz)
             print td
             timestamp = msgDate - td
             mytz = "%+4.4d" % (tz / -(60 * 60) * 100) # time.timezone counts westwards!
